import assert from "assert";
import chalk from "chalk";
import prettyMilliseconds from "pretty-ms";
import { Runner } from "../runner.js";
export function runTasksWithCLIRunner(system, ...tasks) {
    return new CLIRunner({ system, concurrency: system.numCPUs }).runTasks(...tasks);
}
class CLIRunner extends Runner {
    constructor(options) {
        super(options);
        this._errored = false;
        this._startTimes = new WeakMap();
        this._system = options.system;
    }
    onTaskStart(task) {
        this._startTimes.set(task, Date.now());
        if (this._errored) {
            return; // Skip logging.
        }
        this._system.log(`Starting ${chalk.blue(task.options.name)}`);
    }
    onTaskFinish(task) {
        if (this._errored) {
            return; // Skip logging.
        }
        const took = Date.now() - checkDefined(this._startTimes.get(task));
        this._system.log(`Finished ${chalk.green(task.options.name)} in ${prettyMilliseconds(took)}`);
    }
    onTaskError(task, e) {
        if (this._errored) {
            return; // Skip logging.
        }
        this._errored = true;
        this._system.error(`Error in ${chalk.red(task.options.name)}`);
        this._system.error(`${e}`);
    }
}
function checkDefined(value) {
    assert(value);
    return value;
}
//# sourceMappingURL=runner.js.map