import os from "os";
import path from "path";
export function taskSorter(a, b) {
    return stringSorter(a.options.name, b.options.name);
}
export function stringSorter(a, b) {
    return a.localeCompare(b);
}
export function simplifyPath(p) {
    let homedir = os.homedir();
    if (!p.endsWith(path.sep)) {
        homedir += path.sep;
    }
    if (p.startsWith(homedir)) {
        p = p.slice(homedir.length);
        return `~${path.sep}${p}`;
    }
    return p;
}
/**
 * UserError is a special error that, when caught in the CLI will be printed
 * as a message only, without stacktrace. Use this instead of process.exit.
 */
export class UserError extends Error {
    constructor(message) {
        super(message);
    }
}
/**
 * When thrown, ExitCodeError causes the process to exit with a specific error code,
 * without logging anything.
 */
export class ExitCodeError {
    constructor(exitCode) {
        this.exitCode = exitCode;
    }
}
export function createSystem(process) {
    return {
        log(message) {
            process.stdout.write(message + "\n");
        },
        error(message) {
            process.stderr.write(message + "\n");
        },
        process,
        numCPUs: os.cpus().length,
    };
}
//# sourceMappingURL=utils.js.map